@@ -1272,10 +1272,17 @@ def create_bootstrap_script(extra_text, python_version=''):
 """Customization code for virtualenv_ bootstrap scripts.
 
 This code is only useful when included in a virtualenv_ bootstrap script.  It
-uses virtualenv_'s supported hook to enhance and modify the script's
+uses virtualenv_'s supported hooks to enhance and modify the script's
 behaviour.
 
 .. _virtualenv: http://pypi.python.org/pypi/virtualenv
+.. _pip: http://pypi.python.org/pypi/pip
+.. _easy_install: http://packages.python.org/distribute/easy_install.html
+.. _distribute: http://pypi.python.org/pypi/distribute
+
+.. |doc/BOOTSTRAP.PY.txt| replace:: :ref:`bootstrap.py`
+.. |doc/BOOTSTRAP.CFG.txt| replace:: :ref:`bootstrap.cfg`
+.. |optparse.Values| replace:: :mod:`optparse`\ *.Values*
 
 """
 
@@ -1300,10 +1307,10 @@ from os.path import exists
 
 #: File name (or path) for the default configuration file.
 #:
-#: .. note:: During script generation, the original customization source has a
-#:   ``DEFAULT_CONFIG_FILE_NAME`` token (with surrounding ``$`` characters),
+#: .. NOTE:: During script generation, the original customization source has a
+#:   ``DEFAULT_CONFIG_FILE_NAME`` token (with surrounding ``$`` characters)
 #:   which is replaced with the relative path to the bootstrap configuration
-#:   file.
+#:   file when it is included in the bootstrap script.
 # Meta-Note: The above note is written in such a way as to make sense both in
 #            the original source module as well as in the generated bootstrap
 #            script. :)
@@ -1317,7 +1324,7 @@ _supported_installers = {}
 #: Mapping of configuration file sections and their lines of text.
 #:
 #: The lines are interpreted differently depending on the section.  This is why
-#: ConfigParser is not used, for example.
+#: :mod:`ConfigParser` is not used.
 #:
 # This is stored globally because it is read before command-line arguments are
 # fully processed and there is no way to pass on this data to subsequent
@@ -1335,8 +1342,11 @@ def extend_parser(parser):
 
     :parameter optparse.OptionParser parser: The command-line parser to use.
 
-    .. todo:: Find a way to automatically include the output of the
-      :option:`--help` options in the generated Sphinx docs.
+    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for the full list of command-line
+       options, including the new and modified ones.
+
+    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on the configuration file
+       and overriding default option values.
 
     """
     parser.set_usage('%prog [OPTIONS] [CONFIG_FILE]')
@@ -1352,29 +1362,27 @@ def extend_parser(parser):
       '--setuptools',
       dest='use_setuptools',
       action='store_true',
-      help='Use Setuptools instead of Distribute.')
+      help='Use setuptools instead of distribute.')
     parser.remove_option('--unzip-setuptools')
     parser.add_option(
       '--zip-setuptools',
       dest='zip_setuptools',
       action='store_true',
-      help='Do not unzip Setuptools (or Distribute?) when installing it.')
+      help='Do not unzip setuptools (or distribute) when installing it.')
     parser.add_option(
       '--pip-install-options',
       dest='pip_install_options',
       metavar='OPTIONS',
       action='store',
       help='Additional command line options for "pip install". (Default is '
-        '"".)  Set this to a quoted string of options just as you would '
-        'give on the command line.')
+        '"".)')
     parser.add_option(
       '--easy_install-options',
       dest='easy_install_options',
       metavar='OPTIONS',
       action='store',
       help='Additional command line options for "easy_install". (Default is '
-        '"-Z".)  Set this to a quoted string of options just as you would '
-        'give on the command line.')
+        '"-Z".)')
     parser.set_defaults(
       pip_install_options='',
       easy_install_options='-Z')
@@ -1413,14 +1421,14 @@ def _get_config_file_paths():
     """Return paths in which to search for the bootstrap configuration file.
 
     This function first looks on the command-line for a manually specified
-    configuration file.  It one is given, then that is returned as the only
+    configuration file.  If one is given, then that is returned as the only
     file path in which to search.  Otherwise, the returned file paths are the
     default configuration file name in the current directory and in the
     :file:`etc` sub-directory of the current directory.
 
     :returns: The file paths in which to search and whether or not the path was
       specified manually.
-    :rtype: (iterable of strings, bool)
+    :rtype: iterable of `tuple`\s of (`str`, `bool`)
 
     """
     file_name = _DEFAULT_CONFIG_FILE_NAME
@@ -1447,7 +1455,7 @@ def _parse_bootstrap_config(file_):
 
     There is no special line processing except for the ``[options]`` section,
     which expects lines in the form of :samp:`{option_name} = {value}` with any
-    amount of space around the ``=`` sign.  This section is automatically
+    amount of space around the equal sign.  This section is automatically
     parsed into a sub-dictionary instead of a list.
 
     Also all blank lines and lines starting with a ``#`` (i.e. comments) are
@@ -1455,7 +1463,7 @@ def _parse_bootstrap_config(file_):
 
     :returns: A configuration dictionary with section names as keys and text
       lines as values (except for the ``options`` key, see above.)
-    :rtype: {string: iterable of strings}
+    :rtype: `dict` of {`str`: iterable of `str`}
 
     """
     config = {}
@@ -1469,7 +1477,7 @@ def _parse_bootstrap_config(file_):
             config.setdefault(current_section, [])
             continue
         if current_section == 'options':
-            option, value = line.split('=')
+            option, value = line.split('=', 1)
             option = option.strip()
             value = value.strip()
             line = (option, value)
@@ -1484,13 +1492,17 @@ def _parse_bootstrap_config(file_):
 
 
 def adjust_options(options, args):
-    """virtualenv hook to adjust the parsed command-line options and args.
+    """virtualenv_ hook to adjust the parsed command-line options and args.
 
     This function just sets the home directory to the current directory and
-    maps some new command-line options to their original counterparts.
+    maps some of the new command-line options to their original counterparts.
 
-    :parameter optparse.Values options: The parsed command-line options.
-    :parameter iterable args: Any positional arguments from the command-line.
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
+    :parameter tuple args: Any positional arguments from the command-line.
+
+    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for the full list of command-line
+       options, including the new and modified ones.
 
     """
     home_dir = '.'
@@ -1501,16 +1513,20 @@ def adjust_options(options, args):
 
 
 def after_install(options, home_dir):
-    """virtualenv hook for post-bootstrap customization.
+    """virtualenv_ hook for post-bootstrap customization.
 
-    This function is responsible for all the steps to take after the virtual
-    environment has been created.  Specifically, this function installs all the
-    distributions and runs all the commands specified in the configuration
-    file.
+    This function is responsible for all the steps that take place after the
+    virtual environment has been created.  Specifically, this function installs
+    all the distributions and runs all the commands specified in the
+    configuration file.
 
-    :parameter optparse.Values options: The parsed command-line options.
-    :parameter string home_dir: The home directory of the virtual environment
-      (always ``'.'`` in our case).
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
+    :parameter str home_dir: The home directory of the virtual environment.
+      (This is always set to ``'.'``).
+
+    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to specify what
+       distributions to install and what commands to run.
 
     """
     _install_requirements(options)
@@ -1521,14 +1537,15 @@ def _install_requirements(options):
     """Install all additional requirements specified in the configuration file.
 
     This function iterates over all the configuration sections that match a
-    supported distribution installer (like pip_ and easy_install_) and install
+    supported distribution installer (e.g. pip_ and easy_install_) and installs
     all the distributions listed in those sections with the appropriate
     installer.
 
-    :parameter optparse.Values options: The parsed command-line options.
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
 
-    .. _pip: http://pypi.python.org/pypi/pip
-    .. _easy_install: http://packages.python.org/distribute/easy_install.html
+    .. SEEALSO:: :func:`_pip_install` and :func:`_easy_install` for the
+       specific details on how those two installers are invoked.
 
     """
     for section_name, section_data in _config.items():
@@ -1541,12 +1558,11 @@ def _install_requirements(options):
 def _print_distributions(installer_name, distribution_specs):
     """Notify the user that the given distributions will be installed.
 
-    :parameter string installer_name: The name of the installer program that
-      will be used to install the distributions (e.g. ``pip`` or
-      ``easy_install``).
-    :parameter iterable of strings distribution_specs: The distribution
-      specifiers of the distributions to be installed (e.g.
-      ``['pep8 (>=0.5,<0.6)']``)
+    :parameter str installer_name: The name of the installer program that will
+      be used to install the distributions (e.g. ``pip`` or ``easy_install``).
+    :parameter distribution_specs: The distribution specifiers of the
+      distributions to be installed (e.g. ``['pep8 (>=0.5,<0.6)']``).
+    :type distribution_specs: iterable of `str`
 
     """
     logger.notify('Using %s to install the following distributions:' %
@@ -1564,13 +1580,20 @@ def _pip_install(distribution_specs, options):
     configuration file and those can be additionally overridden via
     command-line argument.
 
-    :parameter iterable of strings distribution_specs: The distribution
-      specifiers of the distributions to be installed (e.g.
-      ``['pep8 (>=0.5,<0.6)']``)
-    :parameter optparse.Values options: The parsed command-line options.
+    :parameter distribution_specs: The distribution specifiers of the
+       distributions to be installed (e.g. ``['pep8 (>=0.5,<0.6)']``).
+    :type distribution_specs: iterable of `str`
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
 
-    .. seealso:: The :func:`_convert_pep314_versions` function for details on
-      distribution specifier formats.
+    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for details on how to override the
+       default :program:`pip install` options from the command-line.
+
+    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to override the
+       default :program:`pip install` options from the configuration file.
+
+    .. SEEALSO:: :func:`_convert_pep314_versions` for details on distribution
+       specifier formats.
 
     """
     installer_opts = 'install ' + options.pip_install_options
@@ -1585,13 +1608,20 @@ def _easy_install(distribution_specs, options):
     configuration file and those can be additionally overridden via
     command-line argument.
 
-    :parameter iterable of strings distribution_specs: The distribution
-      specifiers of the distributions to be installed (e.g.
-      ``['pep8 (>=0.5,<0.6)']``)
-    :parameter optparse.Values options: The parsed command-line options.
+    :parameter distribution_specs: The distribution specifiers of the
+       distributions to be installed (e.g. ``['pep8 (>=0.5,<0.6)']``).
+    :type distribution_specs: iterable of `str`
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
 
-    .. seealso:: The :func:`_convert_pep314_versions` function for details on
-      distribution specifier formats.
+    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for details on how to override the
+       default :program:`easy_install` options from the command-line.
+
+    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to override the
+       default :program:`easy_install` options from the configuration file.
+
+    .. SEEALSO:: :func:`_convert_pep314_versions` for details on distribution
+       specifier formats.
 
     """
     distribution_specs = _convert_pep314_versions(distribution_specs)
@@ -1616,34 +1646,33 @@ def _convert_pep314_versions(distribution_specs):
     If any distribution specifier is in the second form already, it is left
     unchanged, as are distribution names without specified versions.
 
-    :parameter iterable of strings distribution_specs: The distribution
-      specifiers to convert.
+    :parameter distribution_specs: The distribution specifiers to convert.
+    :type distribution_specs: iterable of `str`
     :returns: A new iterable of converted distribution specifiers.
-    :rtype: iterable of strings
-
-    .. _distribute: http://pypi.python.org/pypi/distribute
+    :rtype: iterable of `str`
 
     """
-    converted_distribution_specs = []
+    converted_specs = []
     for distribution_spec in distribution_specs:
         if '(' in distribution_spec and ')' in distribution_spec:
-            distribution_spec = distribution_spec.replace(' (', '').replace(
-              ')', '')
-        converted_distribution_specs.append(distribution_spec)
-    return converted_distribution_specs
+            for character in ' ()':
+                distribution_spec = distribution_spec.replace(character, '')
+        converted_specs.append(distribution_spec)
+    return converted_specs
 
 
 def _install_distribution(installer_cmd, installer_opts, distribution_specs):
     """Install distributions using the given installer.
 
-    The installer program must be in the virtual environment's :file:`bin`/
+    The installer program must be in the virtual environment's :file:`bin` or
     :file:`Scripts` directory.
 
-    :parameter string installer_cmd: The installer program to run (e.g. pip).
-    :parameter string installer_opts: Any additional command-line options to
-      pass to the installer.
-    :parameter iterable of strings distribution_specs: The distribution
-      specifiers of the distributions to install.
+    :parameter str installer_cmd: The installer program to run (e.g. ``pip``).
+    :parameter str installer_opts: Any additional command-line options to pass
+      to the installer.
+    :parameter distribution_specs: The distribution specifiers of the
+       distributions to be installed.
+    :type distribution_specs: iterable of `str`
 
     """
     bin_dir = _get_bin_dir()
@@ -1659,14 +1688,14 @@ def _install_distribution(installer_cmd, installer_opts, distribution_specs):
 
 
 def _get_bin_dir(trailing_slash=False):
-    """Return the platform-specific name for the bin directory.
+    """Return the platform-specific name for the :file:`bin` directory.
 
     On POSIX systems it is :file:`bin` and on Windows systems it is
     :file:`Scripts`.
 
-    :parameter bool trailing_slash: If True, a platform-specific trailing slash
-      will be append to the returned directory name.
-    :rtype: string
+    :parameter bool trailing_slash: If `True`, a platform-specific trailing
+      slash will be append to the returned directory name.
+    :rtype: `str`
 
     """
     if sys.platform == 'win32':
@@ -1681,14 +1710,15 @@ def _get_bin_dir(trailing_slash=False):
 def _run_commands(options):
     """Run all additional commands specified in the configuration file.
 
-    Commands can use the token ``$bin$`` to represent the platform-specific bin
-    directory, including a trailing slash.
+    Commands can use the token ``$bin$`` to represent the platform-specific
+    :file:`bin` directory, including a trailing slash.
 
-    :parameter optparse.Values options: The parsed command-line options.
+    :parameter options: The parsed command-line options.
+    :type options: |optparse.Values|
 
-    .. note:: The commands are run in a sub-process but are not run through a
-      shell (e.g. :command:`bash`).  This means so shell features are not
-      available.
+    .. NOTE:: The commands are run in a sub-process but are not run through a
+       shell (e.g. :command:`bash`).  This means shell features are not
+       available.
 
     """
     if 'commands' not in _config or not _config['commands']:
